package com.ebts.system.service;

import java.util.List;

import com.ebts.common.core.entity.Result;
import com.ebts.common.core.entity.model.LoginUser;
import com.ebts.system.entity.SysFile;

/**
 * 文件信息Service接口
 *
 * @author binlin
 * @date 2021-02-17
 */
public interface FileService {
    /**
     * 查询文件信息
     *
     * @param fileId 文件信息ID
     * @return 文件信息
     */
    Result<SysFile> selectFileById(Long fileId);

    /**
     * 查询文件信息列表
     *
     * @param sysFile 文件信息
     * @return 文件信息集合
     */
    Result<List<SysFile>> selectFileList(SysFile sysFile);

    /**
     * 查询文件夹基本信息
     *
     * @return
     */
    Result<List<SysFile>> selectFileFolder();

    /**
     * 新增文件信息
     *
     * @param sysFile 文件信息
     * @return 结果
     */
    Result<SysFile> insertFile(SysFile sysFile);

    /**
     * 修改文件信息
     *
     * @param sysFile 文件信息
     * @return 结果
     */
    Result<Integer> updateFile(SysFile sysFile);

    /**
     * 批量删除文件信息
     *
     * @param fileIds 需要删除的文件信息ID
     * @return 结果
     */
    Result<Integer> deleteFileByIds(Long[] fileIds);

    /**
     * 删除文件信息信息
     *
     * @param fileId 文件信息ID
     * @return 结果
     */
    Result<Integer> deleteFileById(Long fileId);

    /**
     * 下载指定文件
     *
     * @param fileId
     * @param loginUser
     * @return
     */
    Result<SysFile> downloadFile(Long fileId, LoginUser loginUser);

}
